%global pkgname gpd

Name:           gap-pkg-%{pkgname}
Version:        1.46
Release:        2%{?dist}
Summary:        Groupoids, group graphs, and groupoid graphs

License:        GPLv2+
URL:            http://gap-packages.github.io/gpd/
Source0:        https://github.com/gap-packages/gpd/releases/download/v%{version}/%{pkgname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gap-pkg-fga
BuildRequires:  gap-pkg-grape
BuildRequires:  gap-pkg-semigroups

Requires:       gap-core
Requires:       gap-pkg-fga

Suggests:       gap-pkg-semigroups

%description
The Gpd package provides functions for computation with finite groupoids
and their morphisms.

The first part is concerned with the standard constructions for
connected groupoids, and for groupoids with more than one component.
Groupoid morphisms are also implemented, and recent work includes the
implementation of automorphisms of a finite, connected groupoid: by
permutation of the objects; by automorphism of the root group; and by
choice of rays to each object.  The automorphism group of such a
groupoid is also computed, together with an isomorphism of a quotient of
permutation groups.

The second part implements graphs of groups and graphs of groupoids.  A
graph of groups is a directed graph with a group at each vertex and with
isomorphisms between subgroups on each arc.  This construction enables
normal form computations for free products with amalgamation, and for
HNN extensions, when the vertex groups come with their own rewriting
systems.

%prep
%setup -q -n %{pkgname}-%{version}

# Fix end of line encoding
sed -i.orig 's/\r//' examples/ggraph.g
touch -r examples/ggraph.g.orig examples/ggraph.g
rm -f examples/ggraph.g.orig

%build
export LC_ALL=C.UTF-8
mkdir ../pkg
ln -s ../%{pkgname}-%{version} ../pkg
gap -l "$PWD/..;%{_gap_dir}" makedoc.g
rm -fr ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname}-%{version} %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{CHANGES,LICENSE.txt,README}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,tex,toc}

%check
export LC_ALL=C.UTF-8
cd tst
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" testall.g 2>&1 | tee log
if grep -Fq 'Errors detected' log; then false; else true; fi
rm -f log

%files
%doc CHANGES README
%license LICENSE.txt
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/examples
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.46-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Feb 21 2017 Jerry James <loganjerry@gmail.com> - 1.46-1
- New upstream version

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.45-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec  5 2016 Jerry James <loganjerry@gmail.com> - 1.45-1
- New upstream version
- New URLs

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 1.43-1
- New upstream version (bz 1284892)

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.34-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Nov 13 2015 Jerry James <loganjerry@gmail.com> - 1.34-1
- Initial RPM
